lda\_over\_time package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   lda_over_time.models

Submodules
----------

lda\_over\_time.lda\_over\_time module lalala
--------------------------------------

.. automodule:: lda_over_time.lda_over_time
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: lda_over_time
   :members:
   :undoc-members:
   :show-inheritance:
